import { HSL, RGB8, RGBF } from '../interfaces/color-models';
/**
 * Converts HSL colours for either RGB 8 bit or RGB float.
 * HSL colour space is known as HSB in Photoshop.
 */
export declare class FromHSL {
    /**
     * Converts HSL object to RGBF.
     * @param {HSL} hsl
     * @returns {RGBF}
     */
    static toRGBF(hsl: HSL): RGBF;
    /**
     * Converts HSL values to RGBF.
     * @param {number} h
     * @param {number} s
     * @param {number} l
     * @returns {RGBF}
     */
    static toRGBF(h: number, s: number, l: number): RGBF;
    /**
     * Converts HSL object to RGB8.
     * @param {HSL} hsl
     * @returns {RGB8}
     */
    static toRGB8(hsl: HSL): RGB8;
    /**
     * Converts HSL values to RGB8.
     * @param {number} h
     * @param {number} s
     * @param {number} l
     * @returns {RGB8}
     */
    static toRGB8(h: number, s: number, l: number): RGB8;
    private static resolveArguments(h, s?, l?);
}
