import { HSV, RGB8, RGBF } from '../interfaces/color-models';
/**
 * Converts HSL colours for either RGB 8 bit or RGB float.
 * HSV is an alternative version of HSL. Hue component is the same,
 * but S and V are calculated a bit differently from S and L in HSL.
 */
export declare class FromHSV {
    /**
     * Converts HSV object to RGBF.
     * @param {HSV} hsv
     * @returns {RGBF}
     */
    static toRGBF(hsv: HSV): RGBF;
    /**
     * Converts HSV values to RGBF.
     * @param {number} h
     * @param {number} s
     * @param {number} v
     * @returns {RGBF}
     */
    static toRGBF(h: number, s: number, v: number): RGBF;
    /**
     * Converts HSV object to RGB8.
     * @param {HSV} hsv
     * @returns {RGB8}
     */
    static toRGB8(hsv: HSV): RGB8;
    /**
     * Converts HSV values to RGB8.
     * @param {number} h
     * @param {number} s
     * @param {number} v
     * @returns {RGB8}
     */
    static toRGB8(h: number, s: number, v: number): RGB8;
    private static resolveArguments(h, s?, v?);
}
