import { HueHelper } from '../util/helpers';
import { FromRGBF } from './rgbf';
/**
 * Converts HSL colours for either RGB 8 bit or RGB float.
 * HSV is an alternative version of HSL. Hue component is the same,
 * but S and V are calculated a bit differently from S and L in HSL.
 */
export class FromHSV {
    static toRGBF(h, s, v) {
        const args = FromHSV.resolveArguments(h, s, v);
        if (args.s === 0) {
            return { r: v, g: v, b: v };
        }
        const C = args.v * args.s;
        const X = C * (1 - Math.abs((args.h / 60) % 2 - 1));
        const m = args.v - C;
        if (args.h < 60) {
            return HueHelper.hueToRgbMatrix(C, X, 0, m);
        }
        if (args.h < 120) {
            return HueHelper.hueToRgbMatrix(X, C, 0, m);
        }
        if (args.h < 180) {
            return HueHelper.hueToRgbMatrix(0, C, X, m);
        }
        if (args.h < 240) {
            return HueHelper.hueToRgbMatrix(0, X, C, m);
        }
        if (args.h < 300) {
            return HueHelper.hueToRgbMatrix(X, 0, C, m);
        }
        return HueHelper.hueToRgbMatrix(C, 0, X, m);
    }
    static toRGB8(h, s, v) {
        return FromRGBF.toRGB8(FromHSV.toRGBF(h, s, v));
    }
    static resolveArguments(h, s, v) {
        const argumentType = typeof h;
        if (argumentType === 'object' && h !== null) {
            return { h: h.h, s: h.s, v: h.v };
        }
        if (argumentType === 'number') {
            return { h: h, s: s, v: v };
        }
        throw new TypeError('Unknown arguments passed');
    }
}
