import { FromRGBF } from './rgbf';
import { HexHelper } from '../util/helpers';
/**
 * Converter from 8 bit RGB colour model representation into other supported colour models.
 * sRGB colour space with D65 white point is assumed.
 */
export class FromRGB8 {
    static toRGBF(r, g, b) {
        const args = FromRGB8.resolveArguments(r, g, b);
        return {
            r: args.r / 255,
            g: args.g / 255,
            b: args.b / 255
        };
    }
    static toHSL(r, g, b) {
        return FromRGBF.toHSL(FromRGB8.toRGBF(r, g, b));
    }
    static toHSV(r, g, b) {
        return FromRGBF.toHSV(FromRGB8.toRGBF(r, g, b));
    }
    static toXYZ(r, g, b) {
        return FromRGBF.toXYZ(FromRGB8.toRGBF(r, g, b));
    }
    static toHex(r, g, b) {
        const args = FromRGB8.resolveArguments(r, g, b);
        return `${HexHelper.numberToHex(args.r)}${HexHelper.numberToHex(args.g)}${HexHelper.numberToHex(args.b)}`;
    }
    static toRGBAHex(r, g, b, a) {
        const args = FromRGB8.resolveRGBAArguments(r, g, b, a);
        return `${FromRGB8.toHex(args)}${HexHelper.numberToHex(args.a)}`;
    }
    static toARGBHex(r, g, b, a) {
        const args = FromRGB8.resolveRGBAArguments(r, g, b, a);
        return `${HexHelper.numberToHex(args.a)}${FromRGB8.toHex(args)}`;
    }
    static toCssRgb(r, g, b) {
        const args = FromRGB8.resolveArguments(r, g, b);
        return `rgb(${args.r}, ${args.g}, ${args.b})`;
    }
    static toCssRgba(r, g, b, a) {
        const args = FromRGB8.resolveRGBAArguments(r, g, b, a);
        return `rgba(${args.r}, ${args.g}, ${args.b}, ${(args.a / 255).toFixed(2)})`;
    }
    static toLab(r, g, b) {
        return FromRGBF.toLab(FromRGB8.toRGBF(FromRGB8.resolveArguments(r, g, b)));
    }
    static resolveArguments(r, g, b) {
        const argumentType = typeof r;
        if (argumentType === 'object' && r !== null) {
            return { r: r.r, g: r.g, b: r.b };
        }
        if (argumentType === 'number') {
            return { r: r, g: g, b: b };
        }
        throw new TypeError('Unknown arguments passed');
    }
    static resolveRGBAArguments(r, g, b, a) {
        const aType = typeof r;
        const bType = typeof g;
        if (aType === 'object' && r !== null && bType === 'number') {
            return { r: r.r, g: r.g, b: r.b, a: g };
        }
        if (aType === 'number') {
            return { r: r, g: g, b: b, a: a };
        }
        throw new TypeError('Unknown arguments passed');
    }
}
